/**
 * Various project purpose strings in enum form
 *
 * You can use as follows:
 *
 * ```js
 * import { ProjectPurpose } from 'digitalocean-js;
 *
 * console.log(ProjectPurpose.Website); // Prints "Website or blog"
 * ```
 */
export declare enum ProjectPurpose {
    Trying = "Just trying out DigitalOcean",
    Educational = "Class project / Educational purposes",
    Website = "Website or blog",
    WebApp = "Web Application",
    Api = "Service or API",
    Mobile = "Mobile Application",
    MachineLearning = "Machine learning / AI / Data processing",
    IoT = "IoT",
    DevTooling = "Operational / Developer tooling"
}
export declare type ProjectEnvironment = 'Development' | 'Staging' | 'Production';
export interface Project {
    id?: string;
    owner_uuid?: string;
    owner_id?: number;
    name?: string;
    description?: string;
    purpose?: string;
    environment?: ProjectEnvironment;
    is_default?: boolean;
    created_at?: string;
    updated_at?: string;
}
export declare type ProjectResourceStatus = 'ok' | 'not_found' | 'assigned' | 'already_assigned' | 'service_down';
export interface ProjectResource {
    urn: string;
    assigned_at: string;
    links: string;
    status: ProjectResourceStatus;
}
/**
 * Defines the prefixes for various resource types
 *
 * @ignore
 */
export declare const RESOURCE_PREFIX: {
    DOMAIN: string;
    DROPLET: string;
    FLOATING_IP: string;
    LOAD_BALANCER: string;
    SPACE: string;
    VOLUME: string;
};
